# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: fumarole.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'fumarole.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import yellowstone_fumarole_proto.geyser_pb2 as geyser__pb2
try:
  solana__storage__pb2 = geyser__pb2.solana__storage__pb2
except AttributeError:
  solana__storage__pb2 = geyser__pb2.solana_storage_pb2

from yellowstone_fumarole_proto.geyser_pb2 import *

DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0e\x66umarole.proto\x12\x08\x66umarole\x1a\x0cgeyser.proto\",\n\x13GetSlotRangeRequest\x12\x15\n\rblockchain_id\x18\x01 \x01(\x0c\"Q\n\x14GetSlotRangeResponse\x12\x15\n\rblockchain_id\x18\x01 \x01(\x0c\x12\x10\n\x08min_slot\x18\x02 \x01(\x03\x12\x10\n\x08max_slot\x18\x03 \x01(\x03\"+\n\x12GetChainTipRequest\x12\x15\n\rblockchain_id\x18\x01 \x01(\x0c\"\xc1\x01\n\x13GetChainTipResponse\x12\x15\n\rblockchain_id\x18\x01 \x01(\x0c\x12W\n\x17shard_to_max_offset_map\x18\x02 \x03(\x0b\x32\x36.fumarole.GetChainTipResponse.ShardToMaxOffsetMapEntry\x1a:\n\x18ShardToMaxOffsetMapEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x03:\x02\x38\x01\"\x10\n\x0eVersionRequest\"\"\n\x0fVersionResponse\x12\x0f\n\x07version\x18\x01 \x01(\t\":\n\x1bGetConsumerGroupInfoRequest\x12\x1b\n\x13\x63onsumer_group_name\x18\x01 \x01(\t\"9\n\x1a\x44\x65leteConsumerGroupRequest\x12\x1b\n\x13\x63onsumer_group_name\x18\x01 \x01(\t\".\n\x1b\x44\x65leteConsumerGroupResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\"\x1b\n\x19ListConsumerGroupsRequest\"R\n\x1aListConsumerGroupsResponse\x12\x34\n\x0f\x63onsumer_groups\x18\x01 \x03(\x0b\x32\x1b.fumarole.ConsumerGroupInfo\"e\n\x11\x43onsumerGroupInfo\x12\n\n\x02id\x18\x01 \x01(\t\x12\x1b\n\x13\x63onsumer_group_name\x18\x02 \x01(\t\x12\x10\n\x08is_stale\x18\x03 \x01(\x08\x12\x15\n\rblockchain_id\x18\x04 \x01(\x0c\"4\n\x15GetSlotLagInfoRequest\x12\x1b\n\x13\x63onsumer_group_name\x18\x01 \x01(\t\"\xe5\x04\n\x0c\x42lockFilters\x12\x36\n\x08\x61\x63\x63ounts\x18\x01 \x03(\x0b\x32$.fumarole.BlockFilters.AccountsEntry\x12>\n\x0ctransactions\x18\x02 \x03(\x0b\x32(.fumarole.BlockFilters.TransactionsEntry\x12\x34\n\x07\x65ntries\x18\x03 \x03(\x0b\x32#.fumarole.BlockFilters.EntriesEntry\x12;\n\x0b\x62locks_meta\x18\x04 \x03(\x0b\x32&.fumarole.BlockFilters.BlocksMetaEntry\x1aW\n\rAccountsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x35\n\x05value\x18\x02 \x01(\x0b\x32&.geyser.SubscribeRequestFilterAccounts:\x02\x38\x01\x1a_\n\x11TransactionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x39\n\x05value\x18\x02 \x01(\x0b\x32*.geyser.SubscribeRequestFilterTransactions:\x02\x38\x01\x1aS\n\x0c\x45ntriesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x32\n\x05value\x18\x02 \x01(\x0b\x32#.geyser.SubscribeRequestFilterEntry:\x02\x38\x01\x1a[\n\x0f\x42locksMetaEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x37\n\x05value\x18\x02 \x01(\x0b\x32(.geyser.SubscribeRequestFilterBlocksMeta:\x02\x38\x01\"\x95\x01\n\x12\x44ownloadBlockShard\x12\x15\n\rblockchain_id\x18\x01 \x01(\x0c\x12\x11\n\tblock_uid\x18\x02 \x01(\x0c\x12\x11\n\tshard_idx\x18\x03 \x01(\x05\x12\x31\n\x0c\x62lockFilters\x18\x04 \x01(\x0b\x32\x16.fumarole.BlockFiltersH\x00\x88\x01\x01\x42\x0f\n\r_blockFilters\"\x17\n\x04Ping\x12\x0f\n\x07ping_id\x18\x01 \x01(\r\"\x17\n\x04Pong\x12\x0f\n\x07ping_id\x18\x01 \x01(\r\"\x87\x01\n\x0b\x44\x61taCommand\x12<\n\x14\x64ownload_block_shard\x18\x01 \x01(\x0b\x32\x1c.fumarole.DownloadBlockShardH\x00\x12/\n\rfilter_update\x18\x02 \x01(\x0b\x32\x16.fumarole.BlockFiltersH\x00\x42\t\n\x07\x63ommand\"\x1a\n\x18\x42lockShardDownloadFinish\"L\n\rBlockNotFound\x12\x15\n\rblockchain_id\x18\x01 \x01(\x0c\x12\x11\n\tblock_uid\x18\x02 \x01(\x0c\x12\x11\n\tshard_idx\x18\x03 \x01(\x05\"B\n\tDataError\x12,\n\tnot_found\x18\x01 \x01(\x0b\x32\x17.fumarole.BlockNotFoundH\x00\x42\x07\n\x05\x65rror\"\x90\x01\n\x0c\x44\x61taResponse\x12)\n\x06update\x18\x01 \x01(\x0b\x32\x17.geyser.SubscribeUpdateH\x00\x12I\n\x1b\x62lock_shard_download_finish\x18\x02 \x01(\x0b\x32\".fumarole.BlockShardDownloadFinishH\x00\x42\n\n\x08response\"0\n\x0c\x43ommitOffset\x12\x0e\n\x06offset\x18\x01 \x01(\x03\x12\x10\n\x08shard_id\x18\x02 \x01(\x05\"c\n\x15PollBlockchainHistory\x12\x10\n\x08shard_id\x18\x01 \x01(\x05\x12\x11\n\x04\x66rom\x18\x02 \x01(\x03H\x00\x88\x01\x01\x12\x12\n\x05limit\x18\x03 \x01(\x03H\x01\x88\x01\x01\x42\x07\n\x05_fromB\x08\n\x06_limit\"\x8f\x02\n\x0f\x42lockchainEvent\x12\x0e\n\x06offset\x18\x01 \x01(\x03\x12\x15\n\rblockchain_id\x18\x02 \x01(\x0c\x12\x11\n\tblock_uid\x18\x03 \x01(\x0c\x12\x12\n\nnum_shards\x18\x04 \x01(\r\x12\x0c\n\x04slot\x18\x05 \x01(\x04\x12\x18\n\x0bparent_slot\x18\x06 \x01(\x04H\x00\x88\x01\x01\x12\x31\n\x10\x63ommitment_level\x18\x07 \x01(\x0e\x32\x17.geyser.CommitmentLevel\x12\x1b\n\x13\x62lockchain_shard_id\x18\x08 \x01(\x05\x12\x17\n\ndead_error\x18\t \x01(\tH\x01\x88\x01\x01\x42\x0e\n\x0c_parent_slotB\r\n\x0b_dead_error\">\n\x11\x42lockchainHistory\x12)\n\x06\x65vents\x18\x01 \x03(\x0b\x32\x19.fumarole.BlockchainEvent\"L\n\x10JoinControlPlane\x12 \n\x13\x63onsumer_group_name\x18\x01 \x01(\tH\x00\x88\x01\x01\x42\x16\n\x14_consumer_group_name\"\xd6\x01\n\x0e\x43ontrolCommand\x12\x32\n\x0cinitial_join\x18\x01 \x01(\x0b\x32\x1a.fumarole.JoinControlPlaneH\x00\x12/\n\rcommit_offset\x18\x02 \x01(\x0b\x32\x16.fumarole.CommitOffsetH\x00\x12\x34\n\tpoll_hist\x18\x03 \x01(\x0b\x32\x1f.fumarole.PollBlockchainHistoryH\x00\x12\x1e\n\x04ping\x18\x04 \x01(\x0b\x32\x0e.fumarole.PingH\x00\x42\t\n\x07\x63ommand\"\xdb\x01\n\x0f\x43ontrolResponse\x12\x33\n\x04init\x18\x01 \x01(\x0b\x32#.fumarole.InitialConsumerGroupStateH\x00\x12\x35\n\rcommit_offset\x18\x02 \x01(\x0b\x32\x1c.fumarole.CommitOffsetResultH\x00\x12\x30\n\tpoll_hist\x18\x03 \x01(\x0b\x32\x1b.fumarole.BlockchainHistoryH\x00\x12\x1e\n\x04pong\x18\x04 \x01(\x0b\x32\x0e.fumarole.PongH\x00\x42\n\n\x08response\"6\n\x12\x43ommitOffsetResult\x12\x0e\n\x06offset\x18\x01 \x01(\x03\x12\x10\n\x08shard_id\x18\x02 \x01(\x05\"\xce\x01\n\x19InitialConsumerGroupState\x12\x15\n\rblockchain_id\x18\x01 \x01(\x0c\x12]\n\x16last_committed_offsets\x18\x02 \x03(\x0b\x32=.fumarole.InitialConsumerGroupState.LastCommittedOffsetsEntry\x1a;\n\x19LastCommittedOffsetsEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x03:\x02\x38\x01\"8\n\x1b\x43reateConsumerGroupResponse\x12\x19\n\x11\x63onsumer_group_id\x18\x01 \x01(\t\"\x9d\x01\n\x1a\x43reateConsumerGroupRequest\x12\x1b\n\x13\x63onsumer_group_name\x18\x01 \x01(\t\x12<\n\x15initial_offset_policy\x18\x02 \x01(\x0e\x32\x1d.fumarole.InitialOffsetPolicy\x12\x16\n\tfrom_slot\x18\x03 \x01(\x04H\x00\x88\x01\x01\x42\x0c\n\n_from_slot*0\n\x13InitialOffsetPolicy\x12\n\n\x06LATEST\x10\x00\x12\r\n\tFROM_SLOT\x10\x01\x32\xd1\x06\n\x08\x46umarole\x12\\\n\x14GetConsumerGroupInfo\x12%.fumarole.GetConsumerGroupInfoRequest\x1a\x1b.fumarole.ConsumerGroupInfo\"\x00\x12\x61\n\x12ListConsumerGroups\x12#.fumarole.ListConsumerGroupsRequest\x1a$.fumarole.ListConsumerGroupsResponse\"\x00\x12\x64\n\x13\x44\x65leteConsumerGroup\x12$.fumarole.DeleteConsumerGroupRequest\x1a%.fumarole.DeleteConsumerGroupResponse\"\x00\x12\x64\n\x13\x43reateConsumerGroup\x12$.fumarole.CreateConsumerGroupRequest\x1a%.fumarole.CreateConsumerGroupResponse\"\x00\x12I\n\rDownloadBlock\x12\x1c.fumarole.DownloadBlockShard\x1a\x16.fumarole.DataResponse\"\x00\x30\x01\x12\x44\n\rSubscribeData\x12\x15.fumarole.DataCommand\x1a\x16.fumarole.DataResponse\"\x00(\x01\x30\x01\x12L\n\x0bGetChainTip\x12\x1c.fumarole.GetChainTipRequest\x1a\x1d.fumarole.GetChainTipResponse\"\x00\x12\x46\n\tSubscribe\x12\x18.fumarole.ControlCommand\x1a\x19.fumarole.ControlResponse\"\x00(\x01\x30\x01\x12@\n\x07Version\x12\x18.fumarole.VersionRequest\x1a\x19.fumarole.VersionResponse\"\x00\x12O\n\x0cGetSlotRange\x12\x1d.fumarole.GetSlotRangeRequest\x1a\x1e.fumarole.GetSlotRangeResponse\"\x00P\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fumarole_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_GETCHAINTIPRESPONSE_SHARDTOMAXOFFSETMAPENTRY']._loaded_options = None
  _globals['_GETCHAINTIPRESPONSE_SHARDTOMAXOFFSETMAPENTRY']._serialized_options = b'8\001'
  _globals['_BLOCKFILTERS_ACCOUNTSENTRY']._loaded_options = None
  _globals['_BLOCKFILTERS_ACCOUNTSENTRY']._serialized_options = b'8\001'
  _globals['_BLOCKFILTERS_TRANSACTIONSENTRY']._loaded_options = None
  _globals['_BLOCKFILTERS_TRANSACTIONSENTRY']._serialized_options = b'8\001'
  _globals['_BLOCKFILTERS_ENTRIESENTRY']._loaded_options = None
  _globals['_BLOCKFILTERS_ENTRIESENTRY']._serialized_options = b'8\001'
  _globals['_BLOCKFILTERS_BLOCKSMETAENTRY']._loaded_options = None
  _globals['_BLOCKFILTERS_BLOCKSMETAENTRY']._serialized_options = b'8\001'
  _globals['_INITIALCONSUMERGROUPSTATE_LASTCOMMITTEDOFFSETSENTRY']._loaded_options = None
  _globals['_INITIALCONSUMERGROUPSTATE_LASTCOMMITTEDOFFSETSENTRY']._serialized_options = b'8\001'
  _globals['_INITIALOFFSETPOLICY']._serialized_start=3669
  _globals['_INITIALOFFSETPOLICY']._serialized_end=3717
  _globals['_GETSLOTRANGEREQUEST']._serialized_start=42
  _globals['_GETSLOTRANGEREQUEST']._serialized_end=86
  _globals['_GETSLOTRANGERESPONSE']._serialized_start=88
  _globals['_GETSLOTRANGERESPONSE']._serialized_end=169
  _globals['_GETCHAINTIPREQUEST']._serialized_start=171
  _globals['_GETCHAINTIPREQUEST']._serialized_end=214
  _globals['_GETCHAINTIPRESPONSE']._serialized_start=217
  _globals['_GETCHAINTIPRESPONSE']._serialized_end=410
  _globals['_GETCHAINTIPRESPONSE_SHARDTOMAXOFFSETMAPENTRY']._serialized_start=352
  _globals['_GETCHAINTIPRESPONSE_SHARDTOMAXOFFSETMAPENTRY']._serialized_end=410
  _globals['_VERSIONREQUEST']._serialized_start=412
  _globals['_VERSIONREQUEST']._serialized_end=428
  _globals['_VERSIONRESPONSE']._serialized_start=430
  _globals['_VERSIONRESPONSE']._serialized_end=464
  _globals['_GETCONSUMERGROUPINFOREQUEST']._serialized_start=466
  _globals['_GETCONSUMERGROUPINFOREQUEST']._serialized_end=524
  _globals['_DELETECONSUMERGROUPREQUEST']._serialized_start=526
  _globals['_DELETECONSUMERGROUPREQUEST']._serialized_end=583
  _globals['_DELETECONSUMERGROUPRESPONSE']._serialized_start=585
  _globals['_DELETECONSUMERGROUPRESPONSE']._serialized_end=631
  _globals['_LISTCONSUMERGROUPSREQUEST']._serialized_start=633
  _globals['_LISTCONSUMERGROUPSREQUEST']._serialized_end=660
  _globals['_LISTCONSUMERGROUPSRESPONSE']._serialized_start=662
  _globals['_LISTCONSUMERGROUPSRESPONSE']._serialized_end=744
  _globals['_CONSUMERGROUPINFO']._serialized_start=746
  _globals['_CONSUMERGROUPINFO']._serialized_end=847
  _globals['_GETSLOTLAGINFOREQUEST']._serialized_start=849
  _globals['_GETSLOTLAGINFOREQUEST']._serialized_end=901
  _globals['_BLOCKFILTERS']._serialized_start=904
  _globals['_BLOCKFILTERS']._serialized_end=1517
  _globals['_BLOCKFILTERS_ACCOUNTSENTRY']._serialized_start=1155
  _globals['_BLOCKFILTERS_ACCOUNTSENTRY']._serialized_end=1242
  _globals['_BLOCKFILTERS_TRANSACTIONSENTRY']._serialized_start=1244
  _globals['_BLOCKFILTERS_TRANSACTIONSENTRY']._serialized_end=1339
  _globals['_BLOCKFILTERS_ENTRIESENTRY']._serialized_start=1341
  _globals['_BLOCKFILTERS_ENTRIESENTRY']._serialized_end=1424
  _globals['_BLOCKFILTERS_BLOCKSMETAENTRY']._serialized_start=1426
  _globals['_BLOCKFILTERS_BLOCKSMETAENTRY']._serialized_end=1517
  _globals['_DOWNLOADBLOCKSHARD']._serialized_start=1520
  _globals['_DOWNLOADBLOCKSHARD']._serialized_end=1669
  _globals['_PING']._serialized_start=1671
  _globals['_PING']._serialized_end=1694
  _globals['_PONG']._serialized_start=1696
  _globals['_PONG']._serialized_end=1719
  _globals['_DATACOMMAND']._serialized_start=1722
  _globals['_DATACOMMAND']._serialized_end=1857
  _globals['_BLOCKSHARDDOWNLOADFINISH']._serialized_start=1859
  _globals['_BLOCKSHARDDOWNLOADFINISH']._serialized_end=1885
  _globals['_BLOCKNOTFOUND']._serialized_start=1887
  _globals['_BLOCKNOTFOUND']._serialized_end=1963
  _globals['_DATAERROR']._serialized_start=1965
  _globals['_DATAERROR']._serialized_end=2031
  _globals['_DATARESPONSE']._serialized_start=2034
  _globals['_DATARESPONSE']._serialized_end=2178
  _globals['_COMMITOFFSET']._serialized_start=2180
  _globals['_COMMITOFFSET']._serialized_end=2228
  _globals['_POLLBLOCKCHAINHISTORY']._serialized_start=2230
  _globals['_POLLBLOCKCHAINHISTORY']._serialized_end=2329
  _globals['_BLOCKCHAINEVENT']._serialized_start=2332
  _globals['_BLOCKCHAINEVENT']._serialized_end=2603
  _globals['_BLOCKCHAINHISTORY']._serialized_start=2605
  _globals['_BLOCKCHAINHISTORY']._serialized_end=2667
  _globals['_JOINCONTROLPLANE']._serialized_start=2669
  _globals['_JOINCONTROLPLANE']._serialized_end=2745
  _globals['_CONTROLCOMMAND']._serialized_start=2748
  _globals['_CONTROLCOMMAND']._serialized_end=2962
  _globals['_CONTROLRESPONSE']._serialized_start=2965
  _globals['_CONTROLRESPONSE']._serialized_end=3184
  _globals['_COMMITOFFSETRESULT']._serialized_start=3186
  _globals['_COMMITOFFSETRESULT']._serialized_end=3240
  _globals['_INITIALCONSUMERGROUPSTATE']._serialized_start=3243
  _globals['_INITIALCONSUMERGROUPSTATE']._serialized_end=3449
  _globals['_INITIALCONSUMERGROUPSTATE_LASTCOMMITTEDOFFSETSENTRY']._serialized_start=3390
  _globals['_INITIALCONSUMERGROUPSTATE_LASTCOMMITTEDOFFSETSENTRY']._serialized_end=3449
  _globals['_CREATECONSUMERGROUPRESPONSE']._serialized_start=3451
  _globals['_CREATECONSUMERGROUPRESPONSE']._serialized_end=3507
  _globals['_CREATECONSUMERGROUPREQUEST']._serialized_start=3510
  _globals['_CREATECONSUMERGROUPREQUEST']._serialized_end=3667
  _globals['_FUMAROLE']._serialized_start=3720
  _globals['_FUMAROLE']._serialized_end=4569
# @@protoc_insertion_point(module_scope)
